==> haskell-storable-tuple-0.1-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-AcUS3eMcuap4mQ6p0Lhh3O
key:                  storable-tuple-0.1-AcUS3eMcuap4mQ6p0Lhh3O
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  0d91ea574fb149d7f0c8bb095334bfa4
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.2.8/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-AcUS3eMcuap4mQ6p0Lhh3O
depends:
    base-4.16.4.0 base-orphans-0.8.8.2-8pE3LNPkijIA21wki8CJLW
    storable-record-0.0.7-5oW7Anxx4LG94Km9g69Irw
    utility-ht-0.0.17.2-7hfxNAxwKoFLnCNbU4FWYa

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.1-59.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-EnMh2GcOqWRDHNf2LPmB5Q
key:                  storable-tuple-0.1-EnMh2GcOqWRDHNf2LPmB5Q
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  383ea1717946e34f4028e990f4b5f6c1
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-EnMh2GcOqWRDHNf2LPmB5Q
depends:
    base-4.17.2.1 base-orphans-0.9.1-H5ZKrdj0NFhGxOpdRcZ2du
    storable-record-0.0.7-CzHiQHTHJdLEhY7TmtiJLz
    utility-ht-0.0.17.2-CDH9qhWDx4z3BQ085GTPlX

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
